This is the mail archive of the glibc-cvs@sourceware.org mailing list for the glibc project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

GNU C Library master sources branch master updated. glibc-2.17-725-g13e23af


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU C Library master sources".

The branch, master has been updated
       via  13e23af76e64efc055103344bd56d553ceee8512 (commit)
      from  351fe550871f522a19b60f66aa75b96426d67f2f (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://sourceware.org/git/gitweb.cgi?p=glibc.git;a=commitdiff;h=13e23af76e64efc055103344bd56d553ceee8512

commit 13e23af76e64efc055103344bd56d553ceee8512
Author: Carlos O'Donell <carlos@redhat.com>
Date:   Wed May 22 23:22:36 2013 -0400

    Update comments in ldconfig.c and dl-hwcaps.c.
    
    In dl-hwcaps.c the comment read that rounding was done
    to ElfW(Addr), but it's actually rounded to ElfW(Word).
    
    In ldconfig.c we make each comment a sentence and
    mention that the "tls" pseudo-hwcap is just for legacy
    installations where TLS was optional.
    
    ---
    
    2013-05-22  Carlos O'Donell  <carlos@redhat.com>
    
    	* elf/ldconfig.c (is_hwcap_platform): Make comments full setences.
    	(main): Mention "tls" pseudo-hwcap is legacy.
    	* elf/dl-hwcaps.c (_dl_important_hwcaps): Correct rounding comment.

diff --git a/ChangeLog b/ChangeLog
index 04dc3af..665b0a0 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,9 @@
+2013-05-22  Carlos O'Donell  <carlos@redhat.com>
+
+	* elf/ldconfig.c (is_hwcap_platform): Make comments full setences.
+	(main): Mention "tls" pseudo-hwcap is legacy.
+	* elf/dl-hwcaps.c (_dl_important_hwcaps): Correct rounding comment.
+
 2013-05-22  Joseph Myers  <joseph@codesourcery.com>
 
 	* math/gen-libm-test.pl (parse_args): Output only string of
diff --git a/elf/dl-hwcaps.c b/elf/dl-hwcaps.c
index 1b7fe52..94cbf6c 100644
--- a/elf/dl-hwcaps.c
+++ b/elf/dl-hwcaps.c
@@ -68,9 +68,9 @@ _dl_important_hwcaps (const char *platform, size_t platform_len, size_t *sz,
 				      + GLRO(dl_sysinfo_map)->l_addr);
 	    /* The standard ELF note layout is exactly as the anonymous struct.
 	       The next element is a variable length vendor name of length
-	       VENDORLEN (with a real length rounded to ElfW(Addr)), followed
+	       VENDORLEN (with a real length rounded to ElfW(Word)), followed
 	       by the data of length DATALEN (with a real length rounded to
-	       ElfW(Addr)).  */
+	       ElfW(Word)).  */
 	    const struct
 	    {
 	      ElfW(Word) vendorlen;
diff --git a/elf/ldconfig.c b/elf/ldconfig.c
index 13f262d..c7b9eb9 100644
--- a/elf/ldconfig.c
+++ b/elf/ldconfig.c
@@ -174,17 +174,17 @@ is_hwcap_platform (const char *name)
 {
   int hwcap_idx = _dl_string_hwcap (name);
 
   /* Is this a normal hwcap for the machine e.g. fpu?  */
   if (hwcap_idx != -1 && ((1 << hwcap_idx) & hwcap_mask))
     return 1;
 
   /* ... Or is it a platform pseudo-hwcap e.g. i686?  */
   hwcap_idx = _dl_string_platform (name);
   if (hwcap_idx != -1)
     return 1;
 
-  /* ... Or is this one of the extra pseudo-hwcaps that we map beyond
-     _DL_FIRST_EXTRA e.g. tls, or nosegneg?  */
+  /* Is this one of the extra pseudo-hwcaps that we map beyond
+     _DL_FIRST_EXTRA like "tls", or "nosegneg?"  */
   for (hwcap_idx = _DL_FIRST_EXTRA; hwcap_idx < 64; ++hwcap_idx)
     if (hwcap_extra[hwcap_idx - _DL_FIRST_EXTRA] != NULL
 	&& !strcmp (name, hwcap_extra[hwcap_idx - _DL_FIRST_EXTRA]))
@@ -1270,8 +1270,10 @@ main (int argc, char **argv)
 	  add_dir (argv[i]);
     }
 
-  /* The last entry in hwcap_extra is reserved for the "tls"
-     pseudo-hwcap which indicates support for TLS.  */
+  /* The last entry in hwcap_extra is reserved for the "tls" pseudo-hwcap which
+     indicates support for TLS.  This pseudo-hwcap is only used by old versions
+     under which TLS support was optional.  The entry is no longer needed, but
+     must remain for compatibility.  */
   hwcap_extra[63 - _DL_FIRST_EXTRA] = "tls";
 
   set_hwcap ();

-----------------------------------------------------------------------

Summary of changes:
 ChangeLog       |    6 ++++++
@@ -174,17 +174,17 @@ is_hwcap_platform (const char *name)
   int hwcap_idx = _dl_string_hwcap (name);
 
-  /* Is this a normal hwcap for the machine e.g. fpu?  */
+  /* Is this a normal hwcap for the machine like "fpu?"  */
   if (hwcap_idx != -1 && ((1 << hwcap_idx) & hwcap_mask))
     return 1;
@@ -174,17 +174,17 @@ is_hwcap_platform (const char *name)
     return 1;
 
-  /* ... Or is it a platform pseudo-hwcap e.g. i686?  */
+  /* Is this a platform pseudo-hwcap like "i686?"  */
   hwcap_idx = _dl_string_platform (name);
   if (hwcap_idx != -1)
 elf/dl-hwcaps.c |    4 ++--
 elf/ldconfig.c  |   14 ++++++++------
 3 files changed, 16 insertions(+), 8 deletions(-)


hooks/post-receive
-- 
GNU C Library master sources


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]